From 219491518c4f6346f09b33c28c1b9b9215142f19 Mon Sep 17 00:00:00 2001
From: Dmitrii Kuragin <kuragin@chromium.org>
Date: Mon, 29 Aug 2022 13:58:53 -0700
Subject: [PATCH] Fix terminal Emacs flickering during scrolling on Mac OS.

* src/term.c (init_tty): Disable `line_ins_del_ok` when `DARWIN_OS` is
  defined because the optimization causes terminal flickering.
---
 src/term.c | 6 ++++++
 1 file changed, 6 insertions(+)

diff --git a/src/term.c b/src/term.c
index 2e43d89232..e06f2bd9e0 100644
--- a/src/term.c
+++ b/src/term.c
@@ -4390,11 +4390,17 @@ init_tty (const char *name, const char *terminal_type, bool must_succeed)
     = (tty->Wcm->cm_abs
        && (tty->TS_set_window || tty->TS_set_scroll_region || tty->TS_set_scroll_region_1));
 
+#ifdef DARWIN_OS
+  /* Multiline optimization cause terminal flickering on Mac OS.
+     See (Bug#57434) */
+  tty->line_ins_del_ok = 0;
+#else
   tty->line_ins_del_ok
     = (((tty->TS_ins_line || tty->TS_ins_multi_lines)
         && (tty->TS_del_line || tty->TS_del_multi_lines))
        || (tty->scroll_region_ok
            && tty->TS_fwd_scroll && tty->TS_rev_scroll));
+#endif
 
   tty->char_ins_del_ok
     = ((tty->TS_ins_char || tty->TS_insert_mode
-- 
2.37.2.672.g94769d06f0-goog

